@@ -15,8 +15,9 @@
 import json
 from datetime import timedelta
 from os import PathLike
+from pathlib import Path
 from time import sleep
-from typing import Any, Dict, Optional
+from typing import Any, Dict, List, Optional
 
 from ..base import LibraryComponent
 from ..generated.playwright_pb2 import Request
@@ -170,9 +171,17 @@ class Interaction(LibraryComponent):
         secret = self.resolve_secret(
             secret, originals.get("secret") or secret, "secret"
         )
-        self._type_text(
-            selector, secret, delay, clear, log_response=False, strict=self.strict_mode
-        )
+        try:
+            self._type_text(
+                selector,
+                secret,
+                delay,
+                clear,
+                log_response=False,
+                strict=self.strict_mode,
+            )
+        except Exception as e:
+            raise Exception(str(e).replace(secret, "***"))
 
     def _get_original_values(self, local_args: Dict[str, Any]) -> Dict[str, Any]:
         originals = locals_to_params(local_args)
@@ -203,8 +212,8 @@ class Interaction(LibraryComponent):
          If ``secret`` variable is prefixed with `%`, library will resolve
          corresponding environment variable. Example `$Password`` will
          resolve to ``${Password}`` Robot Framework variable. Also
-         ``%ENV_PWD``will resolve to ``%{ENV_PWD}`` environment variable.
-         Using normal Robt Framework variables or plain text will also work,
+         ``%ENV_PWD`` will resolve to ``%{ENV_PWD}`` environment variable.
+         Using normal Robot Framework variables or plain text will also work,
          but then library can not prevent Robot Framework leaking the secrets
          in the output files. Also library will log a warning if library
          can not resolve the secret internally.
@@ -228,7 +237,12 @@ class Interaction(LibraryComponent):
         secret = self.resolve_secret(
             secret, originals.get("secret") or secret, "secret"
         )
-        self._fill_text(selector, secret, log_response=False, strict=self.strict_mode)
+        try:
+            self._fill_text(
+                selector, secret, log_response=False, strict=self.strict_mode
+            )
+        except Exception as e:
+            raise Exception(str(e).replace(secret, "***"))
 
     @keyword(tags=("Setter", "PageContent"))
     def press_keys(self, selector: str, *keys: str):
@@ -571,12 +585,17 @@ class Interaction(LibraryComponent):
         selector: str,
         attribute: SelectAttribute,
         *values,
-    ):
+    ) -> List[str]:
         """Selects options from select element found by ``selector``.
 
         ``selector`` Selector of the select tag.
         See the `Finding elements` section for details about the selectors.
 
+        Returns list of options which keyword was able to select. The type of
+        list item matches to ``attribute`` definition. Example if ``attribute``
+        equals to `label` returned list contains label values. Or in case of
+        `index` it contains list of selected indexes.
+
         Matches based on the chosen attribute with list of ``values``.
         Possible attributes to match options by:
         ``attribute``
@@ -586,15 +605,24 @@ class Interaction(LibraryComponent):
         If no values to select are passed will deselect options in element.
 
         Example:
-        | `Select Options By`    select[name=preferred_channel]    label    Direct mail
-        | `Select Options By`    select[name=interests]    value    males    females    others
-        | `Select Options By`    select[name=possible_channels]    index    0    2
-        | `Select Options By`    select[name=interests]    text     Males    Females
+        | ${selected} =    `Select Options By`    select[name=preferred_channel]    label    Direct mail
+        | List Should Contain Value    ${selected}    Direct mail
+        | ${selected} =    `Select Options By`    select[name=interests]    value    males    females    others
+        | List Should Contain Value    ${selected}    males
+        | List Should Contain Value    ${selected}    females
+        | List Should Contain Value    ${selected}    others
+        | Length Should Be    ${selected}    3
+        | ${selected} =    `Select Options By`    select[name=possible_channels]    index    0    2
+        | List Should Contain Value    ${selected}    0
+        | List Should Contain Value    ${selected}    2
+        | ${selected} =    `Select Options By`    select[name=interests]    text     Males    Females
+        | List Should Contain Value    ${selected}    Males
+        | List Should Contain Value    ${selected}    Females
         """
         matchers = ""
         if not values or len(values) == 1 and not values[0]:
             self.deselect_options(selector)
-            return
+            return []
 
         if attribute is SelectAttribute.value:
             matchers = json.dumps([{"value": s} for s in values])
@@ -608,7 +636,8 @@ class Interaction(LibraryComponent):
                     selector=selector, matcherJson=matchers, strict=self.strict_mode
                 )
             )
-            logger.debug(response.log)
+        logger.debug(response.log)
+        return json.loads(response.json)
 
     @keyword(tags=("Setter", "PageContent"))
     def deselect_options(self, selector: str):
@@ -990,6 +1019,8 @@ class Interaction(LibraryComponent):
         | `Upload File By Selector`    \\#file_input_id    big_file.zip
         """
         with self.playwright.grpc_channel() as stub:
+            if not Path(path).is_file():
+                raise ValueError("Nonexistent input file path")
             response = stub.UploadFileBySelector(
                 Request().FileBySelector(
                     path=str(path), selector=selector, strict=self.library.strict_mode
