@@ -23,7 +23,10 @@ from .data_types import (
     ElementState,
     GeoLocation,
     HttpCredentials,
+    NewPageDetails,
+    Permission,
     Proxy,
+    RecordHar,
     RecordVideo,
     RequestMethod,
     SelectAttribute,
@@ -45,5 +48,6 @@ from .misc import (
     get_variable_value,
     is_same_keyword,
     keyword,
+    spawn_node_process,
 )
 from .robot_booleans import is_falsy, is_truthy
